## [README](../README.md)
## GUIDE LIST

- [Installation and Start](./安装与启动.md)
- [Create Project](./如何创建测试项目.md)
- [Run Project](./如何运行测试项目.md)
- [Cases order](./如何管理测试项目中用例顺序.md)
- [Keywords usage](./如何使用自动提示快捷输入关键字.md)
- [Keywards description](./关键字概要说明.md)
- [Scheduler](./如何使用调度管理.md)
- [How to HTTP API test](./如何创建HTTP接口测试用例.md)
- [TestCase Upload and Download](./上传和下载RobotFramework用例.md)
- [Check Keywords documentaion](./如何查看关键字详细文档.md)
- [Test Report](./查看测试报告.md)